# What is tolor?
- Tolor is simple color libary for python.
- You can use predefined colors or hex codes for coloring.
- Also you can use `gradient` function for smooth colored texts

# How to install?
- First you need open terminal and execute `pip install tolor` command
- After installing you can simple import package with `import tolor` command

# How to use?
- I will show you example code for understand.

```python
from tolor import init, color, gradient

init() # Its important to init

print(f"{color.red}Example red message!{color.reset}")
print(f"{color.hex('#06E978')}Example colored message with hex code!{color.reset}")
print(gradient("blue", "green", "Gradient text from blue to green!"))
print(gradient("#FF0000", "#06E978", "Gradient text with hex!"))
```

- There list of predefined colors: `black`, `red`, `green`, `blue`, `yellow`, `cyan`, `magenta`, `white`, `gray`, `orange`, `pink`, `purple`, `brown`, `lime`, `teal`, `indigo`, `gold`, `silver`, `maroon`

# Ending
- If you liked project and want to support me please leave star on github.
- Thanks for using my libary